---
title: dev
---

# `marvin.cli.dev`

## Functions

### `docs`
```python
def docs()
```
Run the Marvin documentation locally. Equivalent to 'cd docs && mintlify dev' from the Marvin root.

---

**Parent Module:** [`cli`](marvin-cli)
